==> zio-aws-backupgateway_2.12-5.17.104.2-sources.jar: zio/aws/backupgateway/model/ListTagsForResourceResponse.scala <==
package zio.aws.backupgateway.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.backupgateway.model.primitives.ResourceArn
import scala.jdk.CollectionConverters._
final case class ListTagsForResourceResponse(
    resourceArn: Option[ResourceArn] = None,
    tags: Option[Iterable[zio.aws.backupgateway.model.Tag]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.backupgateway.model.ListTagsForResourceResponse = {
    import ListTagsForResourceResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.backupgateway.model.ListTagsForResourceResponse
      .builder()
      .optionallyWith(
        resourceArn.map(value => ResourceArn.unwrap(value): java.lang.String)
      )(_.resourceArn)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly
      : zio.aws.backupgateway.model.ListTagsForResourceResponse.ReadOnly =
    zio.aws.backupgateway.model.ListTagsForResourceResponse
      .wrap(buildAwsValue())
}
object ListTagsForResourceResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.backupgateway.model.ListTagsForResourceResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.backupgateway.model.ListTagsForResourceResponse =
      zio.aws.backupgateway.model.ListTagsForResourceResponse(
        resourceArn.map(value => value),
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def resourceArn: Option[ResourceArn]
    def tags: Option[List[zio.aws.backupgateway.model.Tag.ReadOnly]]
    def getResourceArn: ZIO[Any, AwsError, ResourceArn] =
      AwsError.unwrapOptionField("resourceArn", resourceArn)
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.backupgateway.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.backupgateway.model.ListTagsForResourceResponse
  ) extends zio.aws.backupgateway.model.ListTagsForResourceResponse.ReadOnly {
    override val resourceArn: Option[ResourceArn] = scala
      .Option(impl.resourceArn())
      .map(value => zio.aws.backupgateway.model.primitives.ResourceArn(value))
    override val tags: Option[List[zio.aws.backupgateway.model.Tag.ReadOnly]] =
      scala
        .Option(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.backupgateway.model.Tag.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.backupgateway.model.ListTagsForResourceResponse
  ): zio.aws.backupgateway.model.ListTagsForResourceResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-backupgateway_2.13-5.17.207.1-sources.jar: zio/aws/backupgateway/model/ListTagsForResourceResponse.scala <==
package zio.aws.backupgateway.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.backupgateway.model.primitives.ResourceArn
import scala.jdk.CollectionConverters._
final case class ListTagsForResourceResponse(
    resourceArn: Optional[ResourceArn] = Optional.Absent,
    tags: Optional[Iterable[zio.aws.backupgateway.model.Tag]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.backupgateway.model.ListTagsForResourceResponse = {
    import ListTagsForResourceResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.backupgateway.model.ListTagsForResourceResponse
      .builder()
      .optionallyWith(
        resourceArn.map(value => ResourceArn.unwrap(value): java.lang.String)
      )(_.resourceArn)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly
      : zio.aws.backupgateway.model.ListTagsForResourceResponse.ReadOnly =
    zio.aws.backupgateway.model.ListTagsForResourceResponse
      .wrap(buildAwsValue())
}
object ListTagsForResourceResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.backupgateway.model.ListTagsForResourceResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.backupgateway.model.ListTagsForResourceResponse =
      zio.aws.backupgateway.model.ListTagsForResourceResponse(
        resourceArn.map(value => value),
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def resourceArn: Optional[ResourceArn]
    def tags: Optional[List[zio.aws.backupgateway.model.Tag.ReadOnly]]
    def getResourceArn: ZIO[Any, AwsError, ResourceArn] =
      AwsError.unwrapOptionField("resourceArn", resourceArn)
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.backupgateway.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.backupgateway.model.ListTagsForResourceResponse
  ) extends zio.aws.backupgateway.model.ListTagsForResourceResponse.ReadOnly {
    override val resourceArn: Optional[ResourceArn] = zio.aws.core.internal
      .optionalFromNullable(impl.resourceArn())
      .map(value => zio.aws.backupgateway.model.primitives.ResourceArn(value))
    override val tags
        : Optional[List[zio.aws.backupgateway.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.backupgateway.model.Tag.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.backupgateway.model.ListTagsForResourceResponse
  ): zio.aws.backupgateway.model.ListTagsForResourceResponse.ReadOnly =
    new Wrapper(impl)
}
